@@ -3,12 +3,10 @@
 # BCDI: tools for pre(post)-processing Bragg coherent X-ray diffraction imaging data
 #   (c) 07/2017-06/2019 : CNRS UMR 7344 IM2NP
 #   (c) 07/2019-05/2021 : DESY PHOTON SCIENCE
-#   (c) 06/2021-present : DESY CFEL
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 """Functions related to the validation of input parameters."""
 
-from collections import Sequence
 from numbers import Real, Number
 import numpy as np
 
@@ -271,7 +269,10 @@ def valid_item(
 
     # check the type of obj
     if value is not None and not isinstance(value, allowed_types):
-        raise TypeError(f"{name}: wrong type for value, allowed is {allowed_types}")
+        raise TypeError(
+            f"{name}: wrong type for value, "
+            f"allowed is {allowed_types}, got {type(value)}"
+        )
 
     # check min_included
     if min_included is not None and value is not None:
