@@ -11,20 +11,20 @@ try:
     import hdf5plugin  # for P10, should be imported before h5py or PyTables
 except ModuleNotFoundError:
     pass
+import gc
+from matplotlib import pyplot as plt
 import numpy as np
 from numpy.fft import fftn, fftshift
-from matplotlib import pyplot as plt
+from scipy.interpolate import interp1d
 from scipy.ndimage.measurements import center_of_mass
+import sys
 import tkinter as tk
 from tkinter import filedialog
 import xrayutilities as xu
-from scipy.interpolate import interp1d
-import gc
-import sys
 import bcdi.graph.graph_utils as gu
 from bcdi.experiment.detector import create_detector
 from bcdi.experiment.setup import Setup
-import bcdi.preprocessing.preprocessing_utils as pru
+import bcdi.utils.image_registration as reg
 import bcdi.utils.utilities as util
 import bcdi.utils.validation as valid
 
@@ -71,8 +71,6 @@ actuators = {"rocking_angle": "actuator_1_1"}
 # e.g.  {'rocking_angle': 'actuator_1_3', 'detector': 'data_04', 'monitor': 'data_05'}
 is_series = True  # specific to series measurement at P10
 rocking_angle = "inplane"  # "outofplane" or "inplane"
-follow_bragg = False  # only for energy scans, set to True if the detector
-# was also scanned to follow the Bragg peak
 specfile_name = ""
 # template for ID01: name of the spec file without '.spec'
 # template for SIXS_2018: full path of the alias dictionnary 'alias_dict.txt',
@@ -272,7 +270,6 @@ setup.init_paths(
     save_dir=save_dir,
     specfile_name=specfile_name,
     template_imagefile=template_imagefile,
-    create_savedir=True,
 )
 
 ###################
@@ -376,7 +373,8 @@ mask = util.bin_data(array=mask, binning=phasing_binning, debugging=False)
     numz,
     numy,
     numx,
-) = diff_pattern.shape  # this shape will be used for the calculation of q values
+) = diff_pattern.shape
+# this shape will be used for the calculation of q values
 print(
     f"\nMeasured data shape = {numz}, {numy}, {numx},"
     f" Max(measured amplitude)={np.sqrt(diff_pattern).max():.1f}"
@@ -446,14 +444,11 @@ if simulation:
         eta, 0, 0, inplane_simu, outofplane_simu, delta=(0, 0, 0, 0, 0)
     )
 else:
-    qx, qz, qy, _ = pru.regrid(
+    qx, qz, qy, _ = setup.calc_qvalues_xrutils(
         logfile=logfile,
+        hxrd=hxrd,
         nb_frames=numz,
         scan_number=scan,
-        detector=detector,
-        setup=setup,
-        hxrd=hxrd,
-        follow_bragg=follow_bragg,
     )
 
 if debug:
@@ -546,11 +541,10 @@ if debug:
 
 if align_pattern:
     # align the reconstruction with the initial diffraction data
-    phased_fft, _ = pru.align_diffpattern(
+    phased_fft, _ = reg.align_diffpattern(
         reference_data=diff_pattern,
         data=phased_fft,
-        method="registration",
-        combining_method="subpixel",
+        interpolation_method="subpixel",
     )
 
 phased_fft[np.nonzero(mask)] = 0  # do not take mask voxels into account
@@ -619,7 +613,7 @@ if flag_interact:
         linecut_prtf = np.copy(prtf_matrix)
         print("\nInterpolating the 3D PRTF on nan values, it will take some time ...")
         print(f"nb_nans before interpolation = {np.isnan(linecut_prtf).sum()}")
-        linecut_prtf, nb_filtered, _ = pru.mean_filter(
+        linecut_prtf, nb_filtered, _ = util.mean_filter(
             data=linecut_prtf,
             nb_neighbours=1,
             interpolate="interp_isolated",
