@@ -97,7 +97,6 @@ normalize = "monitor"
 # 'monitor' to return the default monitor values, 'skip' to do nothing
 high_threshold = 500000  # everything above will be considered as hotpixel
 hotpixels_file = ""  # root_folder + 'hotpixels_cristal.npz'
-# root_folder + 'merlin_mask_190222_14keV.h5'  #
 flatfield_file = ""  # root_folder + "flatfield_maxipix_8kev.npz"  #
 template_imagefile = "_master.h5"
 # template for ID01: 'data_mpx4_%05d.edf.gz' or 'align_eiger2M_%05d.edf.gz'
@@ -222,9 +221,7 @@ if data.ndim == 3:
     tilt, _, _, _ = setup.read_logfile(scan_number=scan)
     rocking_curve = np.zeros(numz)
 
-    z0, y0, x0 = tuple(
-        map(lambda x: int(np.rint(x)), bu.find_bragg(data, peak_method=peak_method))
-    )
+    z0, y0, x0 = bu.find_bragg(data, peak_method=peak_method)
 
     if x_bragg is None:  # Bragg peak position not defined by the user, use the max
         x_bragg = x0
@@ -286,7 +283,7 @@ if data.ndim == 3:
     data = data.sum(axis=0)  # concatenate along the axis of the rocking curve
     title = f"data.sum(axis=0)   peak method={peak_method}\n"
 else:  # 2D
-    _, y0, x0 = bu.find_bragg(data, peak_method=peak_method)
+    y0, x0 = bu.find_bragg(data, peak_method=peak_method)
     peak_int = int(data[y0, x0])
     print(
         f"Bragg peak (indices in the eventually binned ROI) at (y, x): {y0}, {x0},"
